@@ -5,7 +5,7 @@ use utf8;
 
 package Neo4j::Driver::ServerInfo;
 # ABSTRACT: Provides Neo4j server address and version
-$Neo4j::Driver::ServerInfo::VERSION = '0.31';
+$Neo4j::Driver::ServerInfo::VERSION = '0.32';
 
 use Carp qw(croak);
 our @CARP_NOT = qw(Neo4j::Driver::Session);
@@ -76,7 +76,7 @@ Neo4j::Driver::ServerInfo - Provides Neo4j server address and version
 
 =head1 VERSION
 
-version 0.31
+version 0.32
 
 =head1 SYNOPSIS
 
@@ -146,9 +146,9 @@ This method may be deprecated and removed in future.
 L<Neo4j::Driver::B<ResultSummary>>
 
 =item * Equivalent documentation for the official Neo4j drivers:
-L<ServerInfo (Java)|https://neo4j.com/docs/api/java-driver/current/index.html?org/neo4j/driver/summary/ServerInfo.html>,
-L<IServerInfo (.NET)|https://neo4j.com/docs/api/dotnet-driver/4.0/html/24780fbc-1b81-92a8-97f6-a484475e18dc.htm>,
-L<ServerInfo (Python)|https://neo4j.com/docs/api/python-driver/current/api.html#serverinfo>
+L<ServerInfo (Java)|https://neo4j.com/docs/api/java-driver/5.2/org.neo4j.driver/org/neo4j/driver/summary/ServerInfo.html>,
+L<IServerInfo (.NET)|https://neo4j.com/docs/api/dotnet-driver/5.2/html/24780fbc-1b81-92a8-97f6-a484475e18dc.htm>,
+L<ServerInfo (Python)|https://neo4j.com/docs/api/python-driver/5.2/api.html#serverinfo>
 
 =back
 
@@ -156,12 +156,15 @@ L<ServerInfo (Python)|https://neo4j.com/docs/api/python-driver/current/api.html#
 
 Arne Johannessen <ajnn@cpan.org>
 
+If you contact me by email, please make sure you include the word
+"Perl" in your subject header to help beat the spam filters.
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2016-2022 by Arne Johannessen.
 
-This is free software, licensed under:
-
-  The Artistic License 2.0 (GPL Compatible)
+This is free software; you can redistribute it and/or modify it under
+the terms of the Artistic License 2.0 or (at your option) the same terms
+as the Perl 5 programming language system itself.
 
 =cut
